PyMoDAQ GUI
###########

.. image:: https://img.shields.io/pypi/v/pymodaq_gui.svg
   :target: https://pypi.org/project/pymodaq_gui/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://codecov.io/gh/PyMoDAQ/pymodaq_gui/branch/5.0.x_dev/graph/badge.svg?token=dCg4zaWeBa 
 :target: https://codecov.io/gh/PyMoDAQ/pymodaq_gui



+-------------+-------------------+------------------+---------------------+
|  Linux      | PyQt5             | PyQt6            | PySide6             |
+=============+===================+==================+=====================+
| Python 3.9  | |39-linux-pyqt5|  | |39-linux-pyqt6| | |39-linux-pyside6|  |
+-------------+-------------------+------------------+---------------------+
| Python 3.10 | |310-linux-pyqt5| ||310-linux-pyqt6| | |310-linux-pyside6| |
+-------------+-------------------+------------------+---------------------+
| Python 3.11 | |311-linux-pyqt5| ||311-linux-pyqt6| | |311-linux-pyside6| |
+-------------+-------------------+------------------+---------------------+
| Python 3.12 | |312-linux-pyqt5| ||312-linux-pyqt6| | |312-linux-pyside6| |
+-------------+-------------------+------------------+---------------------+


.. |39-linux-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.9_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |39-linux-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.9_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |39-linux-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.9_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-linux-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.10_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-linux-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.10_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-linux-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.10_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-linux-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.11_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-linux-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.11_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-linux-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.11_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-linux-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.12_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-linux-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.12_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-linux-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Linux_3.12_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml


+-------------+---------------------+--------------------+-----------------------+
|  Windows    | PyQt5               | PyQt6              | PySide6               |
+=============+=====================+====================+=======================+
| Python 3.9  | |39-windows-pyqt5|  | |39-windows-pyqt6| | |39-windows-pyside6|  |
+-------------+---------------------+--------------------+-----------------------+
| Python 3.10 | |310-windows-pyqt5| ||310-windows-pyqt6| | |310-windows-pyside6| |
+-------------+---------------------+--------------------+-----------------------+
| Python 3.11 | |311-windows-pyqt5| ||311-windows-pyqt6| | |311-windows-pyside6| |
+-------------+---------------------+--------------------+-----------------------+
| Python 3.12 | |312-windows-pyqt5| ||312-windows-pyqt6| | |312-windows-pyside6| |
+-------------+---------------------+--------------------+-----------------------+

.. |39-windows-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.9_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |39-windows-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.9_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |39-windows-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.9_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-windows-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.10_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-windows-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.10_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |310-windows-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.10_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-windows-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.11_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-windows-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.11_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |311-windows-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.11_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-windows-pyqt5| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.12_pyqt5.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-windows-pyqt6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.12_pyqt6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml

.. |312-windows-pyside6| image:: https://raw.githubusercontent.com/PyMoDAQ/pymodaq_gui/badges/5.0.x_dev/tests_Windows_3.12_pyside6.svg
    :target: https://github.com/PyMoDAQ/pymodaq_gui/actions/workflows/tests.yml


.. figure:: http://pymodaq.cnrs.fr/en/latest/_static/splash.png
   :alt: shortcut

PyMoDAQ__, Modular Data Acquisition with Python, is a set of **python** modules used to interface any kind of
experiments. It simplifies the interaction with detector and actuator hardware to go straight to the data acquisition
of interest.

__ https://pymodaq.readthedocs.io/en/stable/?badge=latest

`PyMoDAQ GUI` is a set of utilities (constants, methods and classes) and graphical components
based on the Qt framework that are used to create high level user interfaces.

It contains both simple components to create GUI but also high level ones, for instance to display data objects
such as the one generated using the `pymodaq_data` package.


For instance, you'll find data viewers available out of the box:

.. figure:: https://pymodaq.cnrs.fr/en/latest/_images/data_femto_fs.png

    Specific GUI component to view and manipulate 2D data.



Published under the MIT FREE SOFTWARE LICENSE

GitHub repo: https://github.com/PyMoDAQ

Documentation: http://pymodaq.cnrs.fr/
